InSight Antenna Utilization Geometry

Author: Dustin Buccino

Affiliation: RISE Instrument Operations Engineer, Jet Propulsion Laboratory, California Institute of Technology

Creation Date: 01 June 2017

Last Modified: 21 June 2017

This work was carried out at the Jet Propulsion Laboratory, California Institute of Technology, under a contract with the National Aeronautics and Space Administration. Copyright 2017 California Institute of Technology. U.S. Government sponsorship acknowledged.

# 1 Introduction

The purpose of this document is to describe the geometry of the Medium Gain Antennas (MGA) utilized in the Rotation and Interior Structure Experiment (RISE) onboard the InSight lander. It describes the boresight direction alongside instruction on how to determine which antenna is being utilized at a given time strictly through the geometry.

An example of the geometry calculations is provided utilizing a set of SPICE Kernels on the Planetary Data System’s (PDS) Navigation and Ancillary Information Facility (NAIF) node. In this document, coordinate frames are referred to using the SPICE nomenclature for the frames kernel [1].

The RISE instrument utilizes the X-band telecommunications capability of the InSight lander in combination with the coherent Doppler tracking equipment at the Deep Space Network (DSN) to perform radio science experiments to determine the precession and nutation of the Martian spin axis. [2]

# 2 RISE Antenna Utilization

The InSight lander is equipped with several antennas for both direct-to-Earth (DTE) and relay communications. After landing, The RISE investigation will utilize the two X-band Medium Gain Antennas (MGA). During Mars landing, the InSight lander will attempt to orient itself such that the topographic frame and lander mechanical frame are aligned. The antennas are referred to as the East MGA, mounted with the boresight facing the Eastern direction, and West MGA, mounted with the boresight facing the Western direction. [3]

In SPICE nomenclature, the lander topographic frame is called INSIGHT_TOPO. The antenna frames for the East MGA and West MGA are called INSIGHT_LMGA_EAST and INSIGHT_LMGA_WEST. The antenna frames are relative to the lander mechanical frame, called INSIGHT_LANDER. The geometry of the antennas are shown in Figure 1.

Figure 1. RISE Landed East Medium Gain Antenna (LMGA_EAST) and Landed West Medium Gain Antenna (LMGA_WEST) onboard the InSight lander. The coordinate frame (XYZ) shown is an approximation of the topographic frame (INSIGHT_TOPO).

For additional information on the geometric frames, refer to the SPICE Frames kernel (FK) for the InSight Lander [1].

# 3 Geometry

The simplest way to determine which antenna was used at a given time is to determine the azimuth () of Earth in the InSight lander’s topographic frame. When Earth rises in the east (), the LMGA_EAST antenna will be utilized for communications to Earth. When the Earth sets in the west (), the LMGA_WEST antenna will be utilized for communications to Earth. The NAIF SPICE toolkit and corresponding kernel set for the InSight mission provide the means to compute the azimuth angle of Earth with respect to the InSight lander. The required kernel set includes:

· Leapseconds Kernel (LSK), e.g. naif0012.lsk

· Planetary constants Kernel (PCK), e.g. pck00010.tpc

· Planetary ephemeris Kernel (SPK), e.g. de430s.bsp

· Mars ephemeris Kernel (SPK), e.g. mar097s.bsp

· InSight ephemeris Kernel (SPK), e.g. insight_ls_2016e09oiau2000_v1.bsp

· InSight frames Kernel (FK), e.g. insight_v01.tf

Each kernel can be found on the NAIF node of the PDS (https://naif.jpl.nasa.gov). Note: The user should take care and utilize the current set of valid kernels applicable to the timeframe of interest.

In order to compute the azimuth of Earth, three calls to SPICE are required. First, the ephemeris time (ET) is computed for the time of interest. Second, the state vector of Earth (spice name: EARTH) is computed in the INSIGHT_TOPO frame, with the observer being the InSight lander (spice name: INSIGHT) and proper light-time correction (uplink signal or downlink signal). Finally, the state vector is computed into angles (spherical coordinates), and azimuth is computed from the angles. When using a topographic frame and the SPICE routine recrad_c to compute the spherical coordinates, the azimuth angle is computed as (where is the right ascension output, converted to degrees, of recrad_c). Figure 2 is a flowchart describing this process.

Figure 2. Example flowchart algorithm to compute azimuth of Earth, and determine if the East MGA or West MGA is being utilized at a given time.

Example results are shown below with the above kernel set in Figure 3. It is seen that when Earth rises in the east, the East MGA is used, followed by the West MGA as Earth begins to set.

Figure 3. An example plot of azimuth and elevation of Earth with respect to the InSight Lander. Darker gray shaded colors are when the azimuth angle is less than 180 degrees, indicating the East MGA is utilized.

This is not the only method that can be utilized to determine which antenna is being utilized at a given time. An example is computing the boresight-off-Earth (BOE) angle by the angular separation between the Earth direction and the antenna boresight. The antenna boresights are defined in the InSight frames kernel [1]. With this alternate method, the antenna with the minimum BOE angle is the antenna being utilized. Additional kernels, including spacecraft pointing kernel (CK) and spacecraft clock kernel (SCLK) are required for this computation. It is not explained in detail in this document, but mentioned as an example of an alternate method to determine the antenna utilization.

# References

[1] Semenov, Boris. Insight Frame Definitions Kernel, V0.1, September 3, 2015, https://naif.jpl.nasa.gov/pub/naif/INSIGHT/kernels/fk/insight_v01.tf

[2] Folkner, W.M., Asmar, S.W., Dehant, V., and Warwick, R.W., The Rotation and Interior Structure Experiment (RISE) for the InSight mission to Mars (2012). 43rd Lunar and Planetary Science Conference, 1721. http://www.lpi.usra.edu/meetings/lpsc2012/pdf/1721.pdf

[3] Buccino, D.R., InSight Rotation and Interior Structure Experiment PDS EDR Archive Software Interface Specification, 2015. PDS LID urn:nasa:pds:insight_documents:document_rise:rise_insight_sis_raw